#ifndef ADDRESS_H
#define ADDRESS_H

#include <QObject>
#include <QSharedPointer>
#include <QVector>

#include <QxOrm.h>

#include "export.h"

class Customer;
class Order;

class Address : public QObject
{
    Q_OBJECT
    QX_REGISTER_FRIEND_CLASS(Address)

public:
    typedef QSharedPointer<Customer> CustomerPtr;
    typedef QSharedPointer<Order> OrderPtr;

    explicit Address(QObject *parent = nullptr);

    long id();

    QString street() const;
    void setStreet(const QString &street);

    QString number() const;
    void setNumber(const QString &number);

    QString city() const;
    void setCity(const QString &city);

    quint32 zipcode() const;
    void setZipcode(quint32 zipcode);

    CustomerPtr customer() const;
    void setCustomer(const CustomerPtr &customer);

    OrderPtr order() const;
    void setOrder(const OrderPtr &order);

private:
    long m_id = -1;
    QString m_street;
    QString m_number;
    QString m_city;
    quint32 m_zipcode = 0;

    CustomerPtr m_customer;
    OrderPtr m_order;
};

QX_REGISTER_HPP_QXORM_EXAMPLE(Address, qx::trait::no_base_class_defined, 0)

typedef QSharedPointer<Address> AddressPtr;
typedef QVector<QSharedPointer<Address>> AddressVec;

#endif // ADDRESS_H
