#ifndef MACHINE_H
#define MACHINE_H

#include <QObject>
#include <QSharedPointer>
#include <QVector>

#include <QxOrm.h>

#include "export.h"

class ProductionData;

class Machine : public QObject
{
    Q_OBJECT
    QX_REGISTER_FRIEND_CLASS(Machine)

public:
    typedef QVector<QSharedPointer<ProductionData>> ProductionDataVec;

    enum States {
        Idle = 0,
        Production
    };
    Q_ENUM(States)

    explicit Machine(QObject *parent = nullptr);

    long id();

    States state();
    void setState(States state);

    ProductionDataVec productionData() const;
    void setProductionData(const ProductionDataVec &productionData);

private:
    long m_id = -1;
    States m_state = Idle;
    ProductionDataVec m_productionData;
};

QX_REGISTER_HPP_QXORM_EXAMPLE(Machine, qx::trait::no_base_class_defined, 0)

typedef QSharedPointer<Machine> MachinePtr;
typedef QVector<QSharedPointer<Machine>> MachineVec;

#endif // MACHINE_H
