#include <QCoreApplication>
#include <QScopedPointer>

#include <QxOrm.h>

#include "address.h"
#include "customer.h"
#include "machine.h"
#include "order.h"
#include "orderpiece.h"
#include "productiondata.h"


int main(int argc, char *argv[])
{
    QCoreApplication a(argc, argv);

    QFile::remove("./qxorm.sqlite");

    // Init parameters to connect to database
    qx::QxSqlDatabase::getSingleton()->setDriverName("QSQLITE");
    qx::QxSqlDatabase::getSingleton()->setDatabaseName("./qxorm.sqlite");
    qx::QxSqlDatabase::getSingleton()->setHostName("localhost");
    qx::QxSqlDatabase::getSingleton()->setUserName("root");
    qx::QxSqlDatabase::getSingleton()->setPassword("");
    qx::QxSqlDatabase::getSingleton()->setForceParentIdToAllChildren(true);

    // Create all tables in database
    auto daoError = qx::dao::create_table<Address>();
    daoError = qx::dao::create_table<Customer>();
    daoError = qx::dao::create_table<Machine>();
    daoError = qx::dao::create_table<Order>();
    daoError = qx::dao::create_table<OrderPiece>();
    daoError = qx::dao::create_table<ProductionData>();

    //create a new Order (needs Customer and Address)
    CustomerPtr customer(new Customer());
    customer->setFirstName("Max");
    customer->setLastName("Mustermann");

    AddressPtr invoiceAddress(new Address());
    invoiceAddress->setStreet("Musterstrasse");
    invoiceAddress->setNumber("1a");
    invoiceAddress->setCity("Musterstadt");
    invoiceAddress->setZipcode(12345);
    invoiceAddress->setCustomer(customer);

    customer->setInvoiceAddress(invoiceAddress);

    OrderPtr order(new Order());
    order->setCustomer(customer);

    OrderPtr order2(new Order());
    order2->setCustomer(customer);

    AddressPtr deliveryAddress(new Address());
    deliveryAddress->setStreet("Lieferstrasse");
    deliveryAddress->setNumber("2b");
    deliveryAddress->setCity("Lieferstadt");
    deliveryAddress->setZipcode(54321);

    AddressPtr deliveryAddress2(new Address());
    deliveryAddress2->setStreet("Anderelieferstrasse");
    deliveryAddress2->setNumber("3c");
    deliveryAddress2->setCity("Anderelieferstadt");
    deliveryAddress2->setZipcode(98764);

    deliveryAddress->setOrder(order);
    order->setDeliveryAddress(deliveryAddress);

    deliveryAddress2->setOrder(order2);
    order2->setDeliveryAddress(deliveryAddress2);


    // persist customer, adresses and order to database
    daoError = qx::dao::save(customer);
    daoError = qx::dao::save(invoiceAddress);
    daoError = qx::dao::save(order);
    daoError = qx::dao::save(deliveryAddress);
    daoError = qx::dao::save(order2);
    daoError = qx::dao::save(deliveryAddress2);

    AddressVec addresses;
    qx::dao::fetch_all_with_all_relation(addresses);
    for (auto address : addresses)
    {
        qInfo() << "################### " << (address->order() ? address->order()->id() : -1) << address->id() << address->street();
    }



    return 0;
}
