#ifndef ORDER_H
#define ORDER_H

#include <QObject>
#include <QSharedPointer>
#include <QVector>

#include <QxOrm.h>

#include "export.h"

class Address;
class Customer;
class OrderPiece;
class ProductionData;

class Order : public QObject
{
    Q_OBJECT
    QX_REGISTER_FRIEND_CLASS(Order)

public:
    typedef QSharedPointer<Address> AddressPtr;
    typedef QSharedPointer<Customer> CustomerPtr;
    typedef QVector<QSharedPointer<OrderPiece>> OrderPieceVec;
    typedef QVector<QSharedPointer<ProductionData>> ProductionDataVec;

    enum States {
        New = 0,
        Production,
        Finished
    };
    Q_ENUM(States)

    explicit Order(QObject *parent = nullptr);

    long id() const;

    QDateTime date() const;
    void setDate(const QDateTime &date);

    States state() const;
    void setState(const States &state);

    CustomerPtr customer() const;
    void setCustomer(const CustomerPtr &customer);

    ProductionDataVec productionData() const;
    void setProductionData(const ProductionDataVec &productionData);

    OrderPieceVec orderPieces() const;
    void setOrderPieces(const OrderPieceVec &orderPieces);

    AddressPtr deliveryAddress() const;
    void setDeliveryAddress(const AddressPtr &deliveryAddress);

private:
    long m_id = -1;
    QDateTime m_date = QDateTime::currentDateTimeUtc();
    States m_state = New;
    CustomerPtr m_customer = nullptr;
    ProductionDataVec m_productionData;
    OrderPieceVec m_orderPieces;
    AddressPtr m_deliveryAddress = nullptr;

};

QX_REGISTER_HPP_QXORM_EXAMPLE(Order, qx::trait::no_base_class_defined, 0)

typedef QSharedPointer<Order> OrderPtr;
typedef QVector<QSharedPointer<Order>> OrderVec;

#endif // ORDER_H
