#ifndef ORDERPIECE_H
#define ORDERPIECE_H

#include <QObject>
#include <QSharedPointer>
#include <QVector>

#include <QxOrm.h>

#include "export.h"

class Order;
class ProductionData;

class OrderPiece : public QObject
{
    Q_OBJECT
    QX_REGISTER_FRIEND_CLASS(OrderPiece)

public:
    typedef QSharedPointer<Order> OrderPtr;
    typedef QSharedPointer<ProductionData> ProductionDataPtr;

    explicit OrderPiece(QObject *parent = nullptr);

    long id() const;

    double getWidth() const;
    void setWidth(double value);

    double getHeight() const;
    void setHeight(double value);

    double getLength() const;
    void setLength(double value);

    QString getMaterial() const;
    void setMaterial(const QString &value);

    OrderPtr getOrder() const;
    void setOrder(const OrderPtr &order);

    ProductionDataPtr getProductionData() const;
    void setProductionData(const ProductionDataPtr &productionData);

private:
    long m_id = -1;
    double m_width = 0;
    double m_height = 0;
    double m_length = 0;
    QString m_material = QStringLiteral("unknown");

    OrderPtr m_order;
    ProductionDataPtr m_productionData;
};

QX_REGISTER_HPP_QXORM_EXAMPLE(OrderPiece, qx::trait::no_base_class_defined, 0)

typedef QSharedPointer<OrderPiece> OrderPiecePtr;
typedef QVector<QSharedPointer<OrderPiece>> OrderPieceVec;

#endif // ORDERPIECE_H
