#ifndef PRODUCTIONDATA_H
#define PRODUCTIONDATA_H

#include <QObject>
#include <QSharedPointer>
#include <QVector>

#include <QxOrm.h>

#include "export.h"

class Machine;
class Order;
class OrderPiece;


class ProductionData : public QObject
{
    Q_OBJECT
    QX_REGISTER_FRIEND_CLASS(ProductionData)

public:
    typedef QSharedPointer<Machine> MachinePtr;
    typedef QSharedPointer<Order> OrderPtr;
    typedef QSharedPointer<OrderPiece> OrderPiecePtr;

    explicit ProductionData(QObject *parent = nullptr);

    long id() const;

    quint32 toolId() const;
    void setToolId(const quint32 &toolId);

    quint32 programId() const;
    void setProgramId(const quint32 &programId);

    MachinePtr machine() const;
    void setMachine(const MachinePtr &machine);

    OrderPtr order() const;
    void setOrder(const OrderPtr &order);

    OrderPiecePtr orderPiece() const;
    void setOrderPiece(const OrderPiecePtr &orderPiece);

private:
    long m_id = -1;
    quint32 m_toolId = 0;
    quint32 m_programId = 0;
    MachinePtr m_machine;
    OrderPtr m_order;
    OrderPiecePtr m_orderPiece;
};

QX_REGISTER_HPP_QXORM_EXAMPLE(ProductionData, qx::trait::no_base_class_defined, 0)

typedef QSharedPointer<ProductionData> ProductionDataPtr;
typedef QVector<QSharedPointer<ProductionData>> ProductionDataVec;

#endif // PRODUCTIONDATA_H
